require 'test_helper'

class ToSlugTest < Minitest::Test
  def test_lowercase_string
    str = 'HeLLo'
    assert_equal "hello", str.to_slug
  end

  def test_strip_trailing_space
    str = 'trailing space '
    assert_equal 'trailing-space', str.to_slug
  end

  def test_strip_leading_space
    str = ' leading space'
    assert_equal 'leading-space', str.to_slug
  end

  def test_replace_whitespace_with_dashes
    str = 'Hello World'
    assert_equal 'hello-world', str.to_slug
  end

  def test_keep_numbers_in_slug
    str = "2015 Learning Ruby"
    assert_equal '2015-learning-ruby', str.to_slug
  end

  def test_strip_trailing_dashes
    str = 'trailing dash-'
    assert_equal 'trailing-dash', str.to_slug
  end

  def test_strip_leading_dashes
    str = '-leading dash'
    assert_equal 'leading-dash', str.to_slug
  end

  def test_replace_nspaces_with_one_dash
    str = 'hola    muNdo'
    assert_equal 'hola-mundo', str.to_slug
  end

  def test_no_modification_to_valid_slug_strings
    str = 'a-b-c-d'
    assert_equal 'a-b-c-d', str.to_slug
  end

  def test_remove_double_dashes
    str = 'two--dashes--in--between'
    assert_equal 'two-dashes-in-between', str.to_slug
  end

  def test_consider_acronyms_single_words
    str = "N.Y.P.D. vs. N.S.A. vs. F.B.I."
    assert_equal 'nypd-vs-nsa-vs-fbi', str.to_slug
  end

  def test_no_dashes_for_apostrophes
    str = "Thomas Jefferson's Papers"
    assert_equal 'thomas-jeffersons-papers', str.to_slug
  end

  def test_remove_special_characters
    str = 'xyz!@#$%^&*•¶§∞¢89££¡¿()><?""\':;][]\.,/'
    assert_equal 'xyz89', str.to_slug
  end

  def test_remove_diacritics_as_prescribe_in_latin_diacritics1
    diacritics = "À Á Â Ã Ä Å Æ " +
                  "à á â ã ä å æ " +
                  "Ç È É Ê Ë Ð Ñ " +
                  "ç è é ê ë ð ñ " +
                  "Ì Í Î Ï Ý " +
                  "ì í î ï ý " +
                  "Ò Ó Ô Õ Ö Ø " +
                  "ò ó ô õ ö ø " +
                  "Ù Ú Û Ü " +
                  "ù ú û ü " +
                  "Þ ß"

    expected = %w{a a a a a a ae
                     a a a a a a ae
                     c e e e e d n
                     c e e e e d n
                     i i i i y
                     i i i i y
                     o o o o o o
                     o o o o o o
                     u u u u
                     u u u u
                     th ss
                   }

    output = diacritics.to_slug.split('-')

    output.each_index do |idx|
      assert_equal expected[idx], output[idx]
    end
  end
end